========
pinnwand
========

`pinnwand` is Python pastebin software.

Prerequisites
=============
flask
sqlalchemy
pygments

Usage
=====

Reporting bugs
==============
Bugs are reported best at `pinnwand`'s `project page`_ on github.

License
=======
`pinnwand` is distributed under a 3-clause BSD-style license. See `LICENSE`
for details.

.. _project page: https://github.com/supakeen/pinnwand
